@@ -1,18 +1,14 @@
 # coding: utf-8
 
-# PYTHON IMPORTS
 import os
 import re
 
-# DJANGO IMPORTS
-from django.core.management.base import BaseCommand, CommandError
+from six.moves import input
+
 from django.conf import settings
-from django.utils.six.moves import input
-
-# FILEBROWSER IMPORTS
-from filebrowser.settings import EXTENSION_LIST, EXCLUDE, DIRECTORY, VERSIONS, EXTENSIONS
-from filebrowser.base import FileListing, FileObject
-
+from django.core.management.base import BaseCommand, CommandError
+from filebrowser.base import FileListing
+from filebrowser.settings import DIRECTORY, EXCLUDE, EXTENSION_LIST, VERSIONS
 
 filter_re = []
 for exp in EXCLUDE:
@@ -23,9 +19,11 @@ for k, v in VERSIONS.items():
 
 
 class Command(BaseCommand):
-    args = '<media_path>'
     help = "(Re)Generate image versions."
 
+    def add_arguments(self, parser):
+        parser.add_argument('media_path', nargs=1)
+
     def handle(self, *args, **options):
         media_path = ""
 
@@ -69,7 +67,7 @@ class Command(BaseCommand):
                 else:
                     self.stdout.write('generating all versions for: %s\n' % fileobject.path)
                     for version in VERSIONS:
-                        versionobject = fileobject.version_generate(selected_version)  # FIXME force?
+                        versionobject = fileobject.version_generate(version)  # FIXME force?
 
         # # walkt throu the filebrowser directory
         # # for all/new files (except file versions itself and excludes)
