@@ -1,7 +1,7 @@
 # coding: utf-8
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 # Main FileBrowser Directory. Relative to site.storage.location.
